@@ -57,7 +57,7 @@ static char	*signencrypt_filename;
 static char	*verifydecrypt_filename;
 static int	ascii_arm = 1;
 static int	clipboard = FALSE;
-static int	decrypt = 1;
+static int	decrypt = 0;
 static int	detachedsign = 1;
 static int	encrypt = 0;
 static int	recvkey_fromkeyserver = TRUE;
@@ -65,6 +65,7 @@ static int	selection_received = FALSE;
 static int	sendkey_tokeyserver = TRUE;
 static int	sign = 0;
 static int	signencrypt_active_btn = 0;
+static int	verifydecrypt_active_btn = 0;
 
 
 /********************* Utility Routines *********************/
@@ -266,12 +267,15 @@ void
 on_decrypt_btn_toggled                 (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
 {
-  	GtkWidget *passphrase_entry;
+  	GtkWidget *widget;
 
-	decrypt = GTK_TOGGLE_BUTTON (togglebutton)->active;
-  	passphrase_entry = get_widget (verify_decrypt, 
-				       "verify_decrypt_passphrase");
-	gtk_widget_set_sensitive (passphrase_entry, decrypt);
+	verifydecrypt_active_btn = 1;
+ 	if (GTK_TOGGLE_BUTTON (togglebutton)->active) {
+		decrypt = 1;
+		widget = get_widget (verify_decrypt, 
+				"verify_decrypt_passphrase");
+		gtk_widget_set_sensitive (widget, TRUE);
+	}
 }
 
 
@@ -293,7 +297,6 @@ on_detachedsign_btn_toggled            (GtkToggleButton *togglebutton,
 				"signencrypt_usernamecombo");
 		gtk_widget_set_sensitive (widget, FALSE);
 	}
-
 }
 
 
@@ -452,6 +455,22 @@ on_signencrypt_btn_toggled             (GtkToggleButton *togglebutton,
 }
 
 
+void
+on_verify_btn_toggled                  (GtkToggleButton *togglebutton,
+                                        gpointer         user_data)
+{
+  	GtkWidget *widget;
+
+	verifydecrypt_active_btn = 0;
+ 	if (GTK_TOGGLE_BUTTON (togglebutton)->active) {
+		decrypt = 0;
+		widget = get_widget (verify_decrypt, 
+				"verify_decrypt_passphrase");
+		gtk_widget_set_sensitive (widget, FALSE);
+	}
+}
+
+
 /********************* Sign & Encrypt *********************/
 
 void
@@ -637,7 +656,6 @@ on_verify_decrypt_ok_clicked           (GtkButton       *button,
 	int outfile = 0;
 	int result;
   	GtkWidget *log_textbox;
-  	GtkWidget *decrypt_btn;
   	GtkWidget *outfile_btn;
   	GtkWidget *verify_decrypt_file;
   	GtkWidget *passphrase_entry;
@@ -662,7 +680,6 @@ on_verify_decrypt_ok_clicked           (GtkButton       *button,
 	}
 
 
-  	decrypt_btn = get_widget (verify_decrypt, "decrypt_btn");
 	if (decrypt) {
   		passphrase_entry = get_widget (verify_decrypt, 
 					       "verify_decrypt_passphrase");
@@ -718,16 +735,21 @@ void
 on_decrypt_activate                    (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  	GtkWidget	*decrypt_btn;
+  	GtkWidget	*active_btn;
   	GtkWidget	*decrypt_clipboard_btn;
 	GtkWidget	*verify_decrypt_file;
 	GtkWidget	*verify_decrypt_file_btn;
 
 	verify_decrypt = create_verify_decrypt ();
 
-  	decrypt_btn = get_widget (verify_decrypt, "decrypt_btn");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (decrypt_btn),
-			decrypt);
+	if (verifydecrypt_active_btn == 1) {
+		active_btn = get_widget (verify_decrypt, "decrypt_btn");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (active_btn), TRUE);
+	} else {
+		active_btn = get_widget (verify_decrypt, "verify_btn");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (active_btn), TRUE);
+	}
+
 
   	verify_decrypt_file = get_widget (verify_decrypt,
 			"verify_decrypt_file");
@@ -1197,3 +1219,4 @@ on_verify_decrypt_selection_received   (GtkWidget       *widget,
 }
 
 
+
